@@ -20,10 +20,9 @@ dx for tab-completion, resolving naming conflicts, etc.
 '''
 
 from __future__ import print_function, unicode_literals, division, absolute_import
-
 import sys
 
-from ..packages.argcomplete import warn
+from argcomplete import warn
 from collections import namedtuple, OrderedDict
 import dxpy
 from .resolver import (get_first_pos_of_char, get_last_pos_of_char, clean_folder_path, resolve_path,
@@ -102,10 +101,8 @@ def get_folder_matches(text, delim_pos, dxproj, folderpath):
     and be in escaped form for consumption by the command-line.
     '''
     try:
-        folder_names = map(lambda folder_name:
-                               folder_name[folder_name.rfind('/') + 1:],
-                           dxproj.list_folder(folder=folderpath,
-                                              only='folders')['folders'])
+        folders = dxproj.list_folder(folder=folderpath, only='folders')['folders']
+        folder_names = [name[name.rfind('/') + 1:] for name in folders]
         if text != '' and delim_pos != len(text) - 1:
             folder_names += ['.', '..']
         prefix = text[:delim_pos + 1]
@@ -134,7 +131,6 @@ def get_data_matches(text, delim_pos, dxproj, folderpath, classname=None,
     Members of the returned list are guaranteed to start with *text*
     and be in escaped form for consumption by the command-line.
     '''
-
     #unescaped_text = unescape_completion_name_str(text[delim_pos + 1:])
     unescaped_text = text[delim_pos + 1:]
 
@@ -178,7 +174,6 @@ def path_completer(text, expected=None, classes=None, perm_level=None,
     Returns a list of matches to the text and restricted by the
     requested parameters.
     '''
-
     colon_pos = get_last_pos_of_char(':', text)
     slash_pos = get_last_pos_of_char('/', text)
     delim_pos = max(colon_pos, slash_pos)
@@ -335,7 +330,7 @@ class LocalCompleter():
         self.matches = []
 
     def _populate_matches(self, prefix):
-        from ..packages.argcomplete.completers import FilesCompleter
+        from argcomplete.completers import FilesCompleter
         completer = FilesCompleter()
         self.matches = completer(prefix)
 
@@ -421,27 +416,47 @@ class InstanceTypesCompleter():
 
     # AWS
     aws_preferred_instance_types = OrderedDict()
-    for i in (InstanceTypeSpec('mem1_ssd1_x2', 3.8, 32, 2),
-              InstanceTypeSpec('mem1_ssd1_x4', 7.5, 80, 4),
-              InstanceTypeSpec('mem1_ssd1_x8', 15.0, 160, 8),
-              InstanceTypeSpec('mem1_ssd1_x16', 30.0, 320, 16),
-              InstanceTypeSpec('mem1_ssd1_x32', 60.0, 640, 32),
+    for i in (InstanceTypeSpec('mem1_ssd1_v2_x2', 4.0, 50, 2),
+              InstanceTypeSpec('mem1_ssd1_v2_x4', 8.0, 100, 4),
+              InstanceTypeSpec('mem1_ssd1_v2_x8', 16.0, 200, 8),
+              InstanceTypeSpec('mem1_ssd1_v2_x16', 32.0, 400, 16),
+              InstanceTypeSpec('mem1_ssd1_v2_x36', 72.0, 900, 36),
+              InstanceTypeSpec('mem1_ssd1_v2_x72', 144.0, 1800, 72),
 
-              InstanceTypeSpec('mem2_ssd1_x2', 7.5, 32, 2),
-              InstanceTypeSpec('mem2_ssd1_x4', 15.0, 80, 4),
-              InstanceTypeSpec('mem2_ssd1_x8', 30.0, 160, 8),
+              InstanceTypeSpec('mem2_ssd1_v2_x2', 8.0, 75, 2),
+              InstanceTypeSpec('mem2_ssd1_v2_x4', 16.0, 150, 4),
+              InstanceTypeSpec('mem2_ssd1_v2_x8', 32.0, 300, 8),
+              InstanceTypeSpec('mem2_ssd1_v2_x16', 64.0, 600, 16),
+              InstanceTypeSpec('mem2_ssd1_v2_x32', 128.0, 1200, 32),
+              InstanceTypeSpec('mem2_ssd1_v2_x48', 144.0, 1800, 48),
+              InstanceTypeSpec('mem2_ssd1_v2_x64', 256.0, 2400, 64),
+              InstanceTypeSpec('mem2_ssd1_v2_x96', 384.0, 3600, 96),
 
-              InstanceTypeSpec('mem3_ssd1_x2', 15.0, 32, 2),
-              InstanceTypeSpec('mem3_ssd1_x4', 30.5, 80, 4),
-              InstanceTypeSpec('mem3_ssd1_x8', 61.0, 160, 8),
-              InstanceTypeSpec('mem3_ssd1_x16', 122.0, 320, 16),
-              InstanceTypeSpec('mem3_ssd1_x32', 244.0, 640, 32),
+              InstanceTypeSpec('mem3_ssd1_v2_x2', 16.0, 75, 2),
+              InstanceTypeSpec('mem3_ssd1_v2_x4', 32.0, 150, 4),
+              InstanceTypeSpec('mem3_ssd1_v2_x8', 64.0, 300, 8),
+              InstanceTypeSpec('mem3_ssd1_v2_x16', 128.0, 600, 16),
+              InstanceTypeSpec('mem3_ssd1_v2_x32', 256.0, 1200, 32),
+              InstanceTypeSpec('mem3_ssd1_v2_x48', 384.0, 1800, 48),
+              InstanceTypeSpec('mem3_ssd1_v2_x64', 512.0, 3200, 64),
+              InstanceTypeSpec('mem3_ssd1_v2_x96', 768.0, 3600, 96),
 
-              InstanceTypeSpec('mem1_ssd2_x2', 3.8, 160, 2),
-              InstanceTypeSpec('mem1_ssd2_x4', 7.5, 320, 4),
-              InstanceTypeSpec('mem1_ssd2_x8', 15, 640, 8),
-              InstanceTypeSpec('mem1_ssd2_x16', 30, 1280, 16),
-              InstanceTypeSpec('mem1_ssd2_x36', 60, 2880, 36)):
+              InstanceTypeSpec('mem3_ssd3_x2', 16.0, 1250, 2),
+              InstanceTypeSpec('mem3_ssd3_x4', 32.0, 2500, 4),
+              InstanceTypeSpec('mem3_ssd3_x8', 64.0, 5000, 8),
+              InstanceTypeSpec('mem3_ssd3_x12', 96.0, 7500, 12),
+              InstanceTypeSpec('mem3_ssd3_x24', 192.0, 15000, 24),
+              InstanceTypeSpec('mem3_ssd3_x48', 384.0, 30000, 48),
+              InstanceTypeSpec('mem3_ssd3_x96', 768.0, 60000, 96),
+
+              InstanceTypeSpec('mem4_ssd1_x128', 1952.0, 3840, 128),
+
+              InstanceTypeSpec('mem1_ssd2_v2_x2', 4.0, 160, 2),
+              InstanceTypeSpec('mem1_ssd2_v2_x4', 8.0, 320, 4),
+              InstanceTypeSpec('mem1_ssd2_v2_x8', 16.0, 640, 8),
+              InstanceTypeSpec('mem1_ssd2_v2_x16', 32.0, 1280, 16),
+              InstanceTypeSpec('mem1_ssd2_v2_x36', 72.0, 2880, 36),
+              InstanceTypeSpec('mem1_ssd2_v2_x72', 144.0, 5760, 72)):
         aws_preferred_instance_types[i.Name] = i
 
     # Azure
@@ -473,18 +488,35 @@ class InstanceTypesCompleter():
     instance_types.update(aws_preferred_instance_types)
     instance_types.update(azure_preferred_instance_types)
 
-    for i in (InstanceTypeSpec('mem1_hdd2_x8', 7.0, 1680, 8),
-              InstanceTypeSpec('mem1_hdd2_x32', 60.5, 3360, 32),
+    for i in (InstanceTypeSpec('mem1_ssd1_x2', 3.8, 32, 2),
+              InstanceTypeSpec('mem1_ssd1_x4', 7.5, 80, 4),
+              InstanceTypeSpec('mem1_ssd1_x8', 15.0, 160, 8),
+              InstanceTypeSpec('mem1_ssd1_x16', 30.0, 320, 16),
+              InstanceTypeSpec('mem1_ssd1_x32', 60.0, 640, 32),
 
-              InstanceTypeSpec('mem2_hdd2_x1', 3.8, 410, 1),
-              InstanceTypeSpec('mem2_hdd2_x2', 7.5, 840, 2),
-              InstanceTypeSpec('mem2_hdd2_x4', 15.0, 1680, 4),
+              InstanceTypeSpec('mem2_ssd1_x2', 7.5, 32, 2),
+              InstanceTypeSpec('mem2_ssd1_x4', 15.0, 80, 4),
+              InstanceTypeSpec('mem2_ssd1_x8', 30.0, 160, 8),
 
-              InstanceTypeSpec('mem3_hdd2_x2', 17.1, 420, 2),
-              InstanceTypeSpec('mem3_hdd2_x4', 34.2, 850, 4),
-              InstanceTypeSpec('mem3_hdd2_x8', 68.4, 1680, 8)):
+              InstanceTypeSpec('mem3_ssd1_x2', 15.0, 32, 2),
+              InstanceTypeSpec('mem3_ssd1_x4', 30.5, 80, 4),
+              InstanceTypeSpec('mem3_ssd1_x8', 61.0, 160, 8),
+              InstanceTypeSpec('mem3_ssd1_x16', 122.0, 320, 16),
+              InstanceTypeSpec('mem3_ssd1_x32', 244.0, 640, 32),
+
+              InstanceTypeSpec('mem1_ssd2_x2', 3.8, 160, 2),
+              InstanceTypeSpec('mem1_ssd2_x4', 7.5, 320, 4),
+              InstanceTypeSpec('mem1_ssd2_x8', 15, 640, 8),
+              InstanceTypeSpec('mem1_ssd2_x16', 30, 1280, 16),
+              InstanceTypeSpec('mem1_ssd2_x36', 60, 2880, 36),
+              InstanceTypeSpec('mem2_hdd2_v2_x2', 8.0, 1000, 2),
+              InstanceTypeSpec('mem2_hdd2_v2_x4', 16.0, 2000, 4),
+
+              InstanceTypeSpec('mem3_hdd2_v2_x2', 16.0, 500, 2),
+              InstanceTypeSpec('mem3_hdd2_v2_x4', 32.0, 1000, 4),
+              InstanceTypeSpec('mem3_hdd2_v2_x8', 64.0, 2000, 8)):
         instance_types[i.Name] = i
-    default_instance_type = aws_preferred_instance_types['mem1_ssd1_x4']
+    default_instance_type = aws_preferred_instance_types['mem1_ssd1_v2_x4']
     instance_type_names = instance_types.keys()
 
     def complete(self, text, state):
